# Changelog

<!--next-version-placeholder-->

## v2.2.0 (2021-11-11)
### Feature
* Add label indexing to load_xyz ([`5e4134f`](https://gitlab.com/jonkragskow/xyz_py/-/commit/5e4134f15ed9457bc148f50f093f191dc82f88eb))

## v2.1.0 (2021-11-09)
### Feature
* Add command line interface ([`40a22bb`](https://gitlab.com/jonkragskow/xyz_py/-/commit/40a22bbd6f5f3514bb5145ada9fae9a81793d9e6))

## v2.0.0 (2021-11-09)


## v1.0.0 (2021-11-09)

